# PySR Showcase
Below is a showcase of papers which have used PySR to discover
or rediscover a symbolic model.
These are sorted by the date of release, with most recent papers at the top.


If you have used PySR in your research,
please submit a pull request to add your paper to [this file](https://github.com/MilesCranmer/PySR/blob/master/docs/papers.yml).


<style>
.row {
  display: flex;
  gap: 25px;
}
.row:after {
  content: "";
  display: table;
  clear: both;
}
.image_column {
  flex: 50%;
  float: left;
  display: flex;
  justify-content: center;
  align-items: center;
  text-align: center;
}
.text_column {
  flex: 50%;
  padding: 10px;
}
.center {
  text-align: center;
}
</style>
